@@ -190,8 +190,7 @@ drm_free(drm_state_t *state)
 	if (state->crtcs != NULL) {
 		drm_crtc_state_t *crtcs = state->crtcs;
 		while (crtcs->crtc_num >= 0) {
-			if (crtcs->r_gamma != NULL)
-				free(crtcs->r_gamma);
+			free(crtcs->r_gamma);
 			crtcs->crtc_num = -1;
 			crtcs++;
 		}
@@ -268,6 +267,16 @@ drm_set_temperature(drm_state_t *state, const color_setting_t *setting)
 			}
 			last_gamma_size = crtcs->gamma_size;
 		}
+
+		/* Initialize gamma ramps to pure state */
+		int ramp_size = crtcs->gamma_size;
+		for (int i = 0; i < ramp_size; i++) {
+			uint16_t value = (double)i/ramp_size * (UINT16_MAX+1);
+			r_gamma[i] = value;
+			g_gamma[i] = value;
+			b_gamma[i] = value;
+		}
+
 		colorramp_fill(r_gamma, g_gamma, b_gamma, crtcs->gamma_size,
 			       setting);
 		drmModeCrtcSetGamma(state->fd, crtcs->crtc_id, crtcs->gamma_size,
