@@ -28,6 +28,7 @@
 #include <glib-object.h>
 
 #include "location-geoclue.h"
+#include "redshift.h"
 
 #ifdef ENABLE_NLS
 # include <libintl.h>
@@ -49,7 +50,7 @@ location_geoclue_init(location_geoclue_state_t *state)
 	state->position = NULL;
 	state->provider = NULL;
 	state->provider_path = NULL;
-	
+
 	return 0;
 }
 
@@ -122,8 +123,8 @@ void
 location_geoclue_free(location_geoclue_state_t *state)
 {
 	if (state->position != NULL) g_object_unref(state->position);
-	if (state->provider != NULL) free(state->provider);
-	if (state->provider_path != NULL) free(state->provider_path);
+	free(state->provider);
+	free(state->provider_path);
 }
 
 void
@@ -185,7 +186,7 @@ location_geoclue_set_option(location_geoclue_state_t *state,
 
 int
 location_geoclue_get_location(location_geoclue_state_t *state,
-			      float *lat, float *lon)
+			      location_t *location)
 {
 	GeocluePositionFields fields;
 	GError *error = NULL;
@@ -199,7 +200,7 @@ location_geoclue_get_location(location_geoclue_state_t *state,
 		g_error_free(error);
 		return -1;
 	}
-	
+
 	if (fields & GEOCLUE_POSITION_FIELDS_LATITUDE &&
 	    fields & GEOCLUE_POSITION_FIELDS_LONGITUDE) {
 		fprintf(stdout, _("According to the geoclue provider"
@@ -210,8 +211,8 @@ location_geoclue_get_location(location_geoclue_state_t *state,
 		return -1;
 	}
 
-	*lat = latitude;
-	*lon = longitude;
+	location->lat = latitude;
+	location->lon = longitude;
 
 	return 0;
 }
